import React from 'react';
import CodeMirror from '@uiw/react-codemirror';
import { markdown, markdownLanguage } from '@codemirror/lang-markdown';
import { indentOnInput } from '@codemirror/language';
import { languages } from '@codemirror/language-data';
import { highlightActiveLine, highlightSpecialChars } from '@codemirror/view';

type MDEditorProps = {
  value: string;
  onChange: (doc: string) => void;
};

function MDEditor({ value, onChange }: MDEditorProps) {
  return (
    <CodeMirror
      value={value}
      extensions={[
        markdown({
          base: markdownLanguage,
          codeLanguages: languages,
          addKeymap: true,
        }),
        indentOnInput(),
        highlightActiveLine(),
        highlightSpecialChars(),
      ]}
      onChange={doc => onChange(doc)}
    />
  );
}

export default MDEditor;
